==> fastestimator-1.0.2.tar.gz: fastestimator-1.0.2/fastestimator/op/numpyop/univariate/to_array.py <==
# Copyright 2019 The FastEstimator Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
from typing import Any, Callable, Dict, Iterable, List, Optional, Union

import numpy as np

from fastestimator.op.numpyop.numpyop import NumpyOp


class ToArray(NumpyOp):
    """Convert data to a numpy array.

    Args:
        inputs: Key(s) of the data to be converted.
        outputs: Key(s) into which to write the converted data.
        mode: What mode(s) to execute this Op in. For example, "train", "eval", "test", or "infer". To execute
            regardless of mode, pass None. To execute in all modes except for a particular one, you can pass an argument
            like "!infer" or "!train".
        dtype: The dtype to apply to the output array, or None to infer the type.
    """
    def __init__(self,
                 inputs: Union[str, Iterable[str], Callable],
                 outputs: Union[str, Iterable[str]],
                 mode: Union[None, str, Iterable[str]] = None,
                 dtype: Optional[str] = None):
        super().__init__(inputs=inputs, outputs=outputs, mode=mode)
        self.dtype = dtype
        self.in_list, self.out_list = True, True

    def forward(self, data: List[Any], state: Dict[str, Any]) -> List[np.ndarray]:
        return [self._apply_transform(elem) for elem in data]

    def _apply_transform(self, data: Any) -> np.ndarray:
        return np.array(data, dtype=self.dtype)

==> fastestimator-1.2.3.tar.gz: fastestimator-1.2.3/fastestimator/op/numpyop/univariate/to_array.py <==
# Copyright 2019 The FastEstimator Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
from typing import Any, Dict, Iterable, List, Optional, Union

import numpy as np

from fastestimator.op.numpyop.numpyop import NumpyOp
from fastestimator.util.traceability_util import traceable


@traceable()
class ToArray(NumpyOp):
    """Convert data to a numpy array.

    Args:
        inputs: Key(s) of the data to be converted.
        outputs: Key(s) into which to write the converted data.
        mode: What mode(s) to execute this Op in. For example, "train", "eval", "test", or "infer". To execute
            regardless of mode, pass None. To execute in all modes except for a particular one, you can pass an argument
            like "!infer" or "!train".
        dtype: The dtype to apply to the output array, or None to infer the type.
    """
    def __init__(self,
                 inputs: Union[str, Iterable[str]],
                 outputs: Union[str, Iterable[str]],
                 mode: Union[None, str, Iterable[str]] = None,
                 dtype: Optional[str] = None):
        super().__init__(inputs=inputs, outputs=outputs, mode=mode)
        self.dtype = dtype
        self.in_list, self.out_list = True, True

    def forward(self, data: List[Any], state: Dict[str, Any]) -> List[np.ndarray]:
        return [self._apply_transform(elem) for elem in data]

    def _apply_transform(self, data: Any) -> np.ndarray:
        return np.array(data, dtype=self.dtype)
